@@ -414,3 +414,86 @@ class FixedLengthTupleS3StoreBackend(FixedLengthTupleStoreBackend):
 
         all_keys = self.list_keys()
         return key in all_keys
+
+
+class FixedLengthTupleGCSStoreBackend(FixedLengthTupleStoreBackend):
+    """
+    Uses a GCS bucket as a store.
+
+    The key to this StoreBackend must be a tuple with fixed length equal to key_length.
+    The filepath_template is a string template used to convert the key to a filepath.
+    There's a bit of regex magic in _convert_filepath_to_key that reverses this process,
+    so that we can write AND read using filenames as keys.
+    """
+    def __init__(
+        self,
+        root_directory,
+        filepath_template,
+        key_length,
+        bucket,
+        prefix,
+        project,
+        forbidden_substrings=None,
+        platform_specific_separator=False
+    ):
+        super(FixedLengthTupleGCSStoreBackend, self).__init__(
+            root_directory=root_directory,
+            filepath_template=filepath_template,
+            key_length=key_length,
+            forbidden_substrings=forbidden_substrings,
+            platform_specific_separator=platform_specific_separator
+        )
+        self.bucket = bucket
+        self.prefix = prefix
+        self.project = project
+
+
+    def _get(self, key):
+        gcs_object_key = os.path.join(
+            self.prefix,
+            self._convert_key_to_filepath(key)
+        )
+
+        from google.cloud import storage
+        gcs = storage.Client(project=self.project)
+        bucket = gcs.get_bucket(self.bucket)
+        gcs_response_object = bucket.get_blob(gcs_object_key)
+        return gcs_response_object.download_as_string().decode("utf-8")
+
+    def _set(self, key, value, content_encoding='utf-8', content_type='application/json'):
+        gcs_object_key = os.path.join(
+            self.prefix,
+            self._convert_key_to_filepath(key)
+        )
+
+        from google.cloud import storage
+        gcs = storage.Client(project=self.project)
+        bucket = gcs.get_bucket(self.bucket)
+        blob = bucket.blob(gcs_object_key)
+        blob.upload_from_string(value.encode(content_encoding), content_type=content_type)
+        return gcs_object_key
+
+    def list_keys(self):
+        key_list = []
+
+        from google.cloud import storage
+        gcs = storage.Client(self.project)
+
+        for blob in gcs.list_blobs(self.bucket, prefix=self.prefix):
+            gcs_object_name = blob.name
+            gcs_object_key = os.path.relpath(
+                gcs_object_name,
+                self.prefix,
+            )
+
+            key = self._convert_filepath_to_key(gcs_object_key)
+            if key:
+                key_list.append(key)
+
+        return key_list
+
+    def has_key(self, key):
+        assert isinstance(key, string_types)
+
+        all_keys = self.list_keys()
+        return key in all_keys
